==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/FileBundleFileFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link FileBundleFile}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class FileBundleFileFieldAttributes extends AbstractBeanAttributesDefinition{

    /** description (Database column: DESCRIPTION) */
    static public AttributeDefinition description =
        new AttributeDefinition("description")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("DESCRIPTION")
                .setMandatory(true)
                .setMaxSize(4000)
                .setType(String.class);

    /** fileBundle (Database column: FILE_BUNDLE_ID) */
    static public AttributeDefinition fileBundle =
        new AttributeDefinition("fileBundle")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("FILE_BUNDLE_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.FileBundle.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.FileBundle.class);

    /** hasValidation (Database column: HAS_VALIDATION) */
    static public AttributeDefinition hasValidation =
        new AttributeDefinition("hasValidation")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("HAS_VALIDATION")
                .setMandatory(true)
                .setMaxSize(255)
                .setDefaultValue("0")
                .setType(boolean.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** isMandatory (Database column: IS_MANDATORY) */
    static public AttributeDefinition isMandatory =
        new AttributeDefinition("isMandatory")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("IS_MANDATORY")
                .setMandatory(true)
                .setMaxSize(255)
                .setDefaultValue("0")
                .setType(boolean.class);

    /** isVersioned (Database column: IS_VERSIONED) */
    static public AttributeDefinition isVersioned =
        new AttributeDefinition("isVersioned")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("IS_VERSIONED")
                .setMandatory(true)
                .setMaxSize(255)
                .setDefaultValue("0")
                .setType(boolean.class);

    /** title (Database column: TITLE) */
    static public AttributeDefinition title =
        new AttributeDefinition("title")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("TITLE")
                .setMandatory(true)
                .setMaxSize(1000)
                .setType(String.class);

    /** fileType (Database column: TYPE_ID) */
    static public AttributeDefinition fileType =
        new AttributeDefinition("fileType")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("TYPE_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.FileType.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.FileType.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(description.getName(),description);
        map.put(fileBundle.getName(),fileBundle);
        map.put(hasValidation.getName(),hasValidation);
        map.put(id.getName(),id);
        map.put(isMandatory.getName(),isMandatory);
        map.put(isVersioned.getName(),isVersioned);
        map.put(title.getName(),title);
        map.put(fileType.getName(),fileType);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/FileBundleFileFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link FileBundleFile}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class FileBundleFileFieldAttributes extends AbstractBeanAttributesDefinition{

    /** description (Database column: DESCRIPTION) */
    static public AttributeDefinition description =
        new AttributeDefinition("description")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("DESCRIPTION")
                .setMandatory(false)
                .setMaxSize(4000)
                .setType(String.class);

    /** fileBundle (Database column: FILE_BUNDLE_ID) */
    static public AttributeDefinition fileBundle =
        new AttributeDefinition("fileBundle")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("FILE_BUNDLE_ID")
                .setMandatory(true)
                .setMaxSize(22)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.FileBundle.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.FileBundle.class);

    /** hasValidation (Database column: HAS_VALIDATION) */
    static public AttributeDefinition hasValidation =
        new AttributeDefinition("hasValidation")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("HAS_VALIDATION")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setDefaultValue("0")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(22)
                .setType(Long.class);

    /** isMandatory (Database column: IS_MANDATORY) */
    static public AttributeDefinition isMandatory =
        new AttributeDefinition("isMandatory")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("IS_MANDATORY")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setDefaultValue("0")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** isVersioned (Database column: IS_VERSIONED) */
    static public AttributeDefinition isVersioned =
        new AttributeDefinition("isVersioned")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("IS_VERSIONED")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setDefaultValue("0")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** title (Database column: TITLE) */
    static public AttributeDefinition title =
        new AttributeDefinition("title")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("TITLE")
                .setMandatory(true)
                .setMaxSize(1000)
                .setType(String.class);

    /** fileType (Database column: TYPE_ID) */
    static public AttributeDefinition fileType =
        new AttributeDefinition("fileType")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_BUNDLE_FILE")
                .setDatabaseId("TYPE_ID")
                .setMandatory(false)
                .setMaxSize(22)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.FileType.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.FileType.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return "description";
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(description.getName(),description);
        map.put(fileBundle.getName(),fileBundle);
        map.put(hasValidation.getName(),hasValidation);
        map.put(id.getName(),id);
        map.put(isMandatory.getName(),isMandatory);
        map.put(isVersioned.getName(),isVersioned);
        map.put(title.getName(),title);
        map.put(fileType.getName(),fileType);

        return map;
    }
}
